
# gradio_molecule3d
A Custom Gradio component to visualize molecules in pdb, sdf or mol2 format.


Developed by Simon Dürr. 

If you use this component for academic work please cite:
3Dmol.js: molecular visualization with WebGL , Nicholas Rego, David Koes, Bioinformatics, Volume 31, Issue 8, April 2015, Pages 1322–1324, https://doi.org/10.1093/bioinformatics/btu829

## How to use

```python
import gradio as gr
from gradio_molecule3d import Molecule3D
```
